package main

import (
	"fmt"
	"log"
	"os"

	cnf "git.ego.cloudns.be/egommerce/go-api-pkg/config"

	"git.ego.cloudns.be/egommerce/catalog-service/internal/app"
	"git.ego.cloudns.be/egommerce/catalog-service/internal/server"
)

func main() {
	if cnf.ErrLoadingEnvs != nil {
		log.Panicln("Error loading .env file", cnf.ErrLoadingEnvs)
	}

	c := server.NewConfig("catalog")
	cArr := c.GetArray()

	doer := server.New(c)
	a := app.NewApp(doer)
	a.RegisterPlugin(app.LoggerPlugin(cArr))
	a.RegisterPlugin(app.CachePlugin(cArr))
	a.RegisterPlugin(app.DatabasePlugin(cArr))
	a.RegisterPlugin(app.EventbusPlugin(cArr))
	a.RegisterPlugin(app.RegistryPlugin(cArr, a))

	while := make(chan struct{})
	err := a.Start(while)
	<-while

	if err != nil {
		log.Fatalf("Failed to start server. Reason: %v\n", err)
		os.Exit(1)
	}

	fmt.Println("Gone")
	os.Exit(0)
}
