package ui

import (
	"context"
	"time"

	"git.ego.cloudns.be/egommerce/api-entities/catalog/dto"
	"git.ego.cloudns.be/egommerce/catalog-service/internal/service"
)

func GetProductList(srv *service.CatalogService, categoryID int, reqID string) ([]dto.GetProductResponseDTO, error) {
	ctx := context.Background()
	res := []dto.GetProductResponseDTO{}

	products, err := srv.GetProductList(ctx, reqID, categoryID)
	if err != nil {
		return nil, err
	}

	for _, v := range products {
		product := dto.GetProductResponseDTO{
			// ID:        v.ID,
			PID:       v.PID,
			Name:      v.Name,
			Price:     v.Price,
			CreatedAt: time.Duration(v.CreatedAt.Unix()),
		}
		if v.UpdatedAt.Unix() > 0 {
			product.UpdatedAt = time.Duration(v.UpdatedAt.Unix())
		}
		res = append(res, product)
	}

	return res, nil
}

func AddProductToBasket(srv *service.CatalogService, productID, qty int, basketID, reqID string) (*dto.AddProductToBasketResponseDTO, error) {
	// ctx := context.Background()
	res := &dto.AddProductToBasketResponseDTO{}

	// product, err := srv.GetProduct(ctx, reqID, productID)
	// if err != nil {
	// 	return res, err
	// }
	// res.ProductID = product.ID

	if err := srv.AddProductToBasket(reqID, basketID, productID, qty); err != nil {
		return res, err
	}
	res.BasketID = basketID

	return res, nil
}

func RemoveProductFromBasket(srv *service.CatalogService, productID, qty int, basketID, reqID string) (*dto.RemoveProductFromBasketResponseDTO, error) {
	res := &dto.RemoveProductFromBasketResponseDTO{}
	if err := srv.RemoveProductFromBasket(reqID, basketID, productID, qty); err != nil {
		return res, err
	}
	res.BasketID = basketID

	return res, nil
}
